use crate::m20241008_095058_create_table_node::Node;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(SensorData::Table)
                    .if_not_exists()
                    .col(big_unsigned(Node::Id))
                    .col(timestamp(SensorData::Timestamp))
                    .primary_key(
                        Index::create()
                            .col(SensorData::Id)
                            .col(SensorData::Timestamp),
                    )
                    .col(float(SensorData::Temperature).default(-127))
                    .col(float(SensorData::Voltage).default(-127))
                    .col(big_unsigned(SensorData::Uptime).default(0))
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-data-node_id")
                            .from(SensorData::Table, SensorData::Id)
                            .to(Node::Table, Node::Id)
                            .on_update(ForeignKeyAction::Cascade)
                            .on_delete(ForeignKeyAction::Cascade),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        // Replace the sample below with your own migration scripts

        manager
            .drop_table(Table::drop().table(SensorData::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum SensorData {
    Table,
    Id, // Mac address
    Timestamp,
    Temperature, // def: -127
    Voltage,     // def: -127
    Uptime,      // def: 0
}
